@@ -428,7 +428,7 @@ class BaseInstance(DataMixin, models.Model):
     def get_play_url(self):
         return ""
 
-    def finish_characters(self, *characters: List[BaseCharacterData]):
+    def finish_characters(self, *characters: BaseCharacterData):
         for character in characters:
             assert character.instance_id == self.id
             character.finish()
@@ -610,6 +610,14 @@ class BasePlayer(models.Model):
                 name += f": {self.character}"
         return name
 
+    @property
+    def team_name(self):
+        if self.run.multiplayer:
+            if self.lobby:
+                return self.lobby.name
+            if self.character:
+                return self.character.instance.name
+
     def get_play_url(self) -> str:
         custom_play_url = getattr(settings, "SIMPL_GET_PLAY_URL", None)
         if custom_play_url:
